@@ -316,8 +316,13 @@ class WorkspaceItem(models.Model):
                     self.delete()
                     return None
                 return real_adapter
-        raise AdapterClassNotFoundError(
-            u'Entry point for %r not found' % self.adapter_class)
+        # When we're here, no adapter has been found. Delete the workspace.
+        logger.error("Entry point for %r not found, "
+                     "deleting workspace item %s.",
+                     self.adapter_class, self)
+        self.delete()
+        return None
+
 
     @property
     def adapter_layer_arguments(self):
